/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton implementation for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "2.3"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SCREENSAVER_TOK = 258,
     SCRSVRS_DIR_TOK = 259,
     SCRSVR_TIMEOUT_TOK = 260,
     SCRN_POWER_TOK = 261,
     XSESSION_DIR_TOK = 262,
     TXTSESSION_DIR_TOK = 263,
     XINIT_TOK = 264,
     SHUTDOWN_TOK = 265,
     TTY_TOK = 266,
     THEMES_DIR_TOK = 267,
     X_SERVER_TOK = 268,
     DFB_INTERFACE_TOK = 269,
     RESET_CONSOLE_TOK = 270,
     X_ARGS_TOK = 271,
     TEMP_FILES_DIR_TOK = 272,
     THEME_TOK = 273,
     WINDOW_TOK = 274,
     RAND_TOK = 275,
     CLEAR_BACKGROUND_TOK = 276,
     LOCK_SESSIONS_TOK = 277,
     NULL_TOK = 278,
     DEFAULT_TXT_COL_TOK = 279,
     DEFAULT_CUR_COL_TOK = 280,
     OTHER_TXT_COL_TOK = 281,
     BG_TOK = 282,
     FONT_TOK = 283,
     BUTTON_OPAC_TOK = 284,
     WIN_OP_TOK = 285,
     SEL_WIN_OP_TOK = 286,
     THEME_RES_TOK = 287,
     EVERYONE_TOK = 288,
     ONLY_ROOT_TOK = 289,
     NO_ONE_TOK = 290,
     WPOLL_TIME_TOK = 291,
     WTEXT_COLOR_TOK = 292,
     WCURSOR_COLOR_TOK = 293,
     WINDOW_LINK_TOK = 294,
     WTYPE_TOK = 295,
     WWIDTH_TOK = 296,
     WHEIGHT_TOK = 297,
     WCOMMAND_TOK = 298,
     WCONTENT_TOK = 299,
     WTEXT_SIZE_TOK = 300,
     WTEXT_TINY_TOK = 301,
     WTEXT_SMALLER_TOK = 302,
     WTEXT_SMALL_TOK = 303,
     WTEXT_MEDIUM_TOK = 304,
     WTEXT_LARGE_TOK = 305,
     WTEXT_ORIENTATION = 306,
     WTEXT_LEFT_TOK = 307,
     WTEXT_CENTER_TOK = 308,
     WTEXT_RIGHT_TOK = 309,
     YES_TOK = 310,
     NO_TOK = 311,
     AUTOLOGIN_TOK = 312,
     USERNAME_TOK = 313,
     PASSWORD_TOK = 314,
     SESSION_TOK = 315,
     RELOGIN_TOK = 316,
     LAST_SESSION_TOK = 317,
     SLEEP_TOK = 318,
     NEXT_TTY_TOK = 319,
     PREV_TTY_TOK = 320,
     POWEROFF_TOK = 321,
     REBOOT_TOK = 322,
     KILL_TOK = 323,
     TEXT_MODE_TOK = 324,
     MENU_KEY_TOK = 325,
     WIN_KEY_TOK = 326,
     ALT_KEY_TOK = 327,
     CTRL_KEY_TOK = 328,
     KEYBINDINGS_TOK = 329,
     USER_TOK = 330,
     LAST_USER_POLICY_TOK = 331,
     LAST_SESSION_POLICY_TOK = 332,
     GLOBAL_TOK = 333,
     NONE_TOK = 334,
     PRE_GUI_TOK = 335,
     POST_GUI_TOK = 336,
     X_SERVER_OFFSET_TOK = 337,
     X_SERVER_TTY_TOK = 338,
     QINGY_TTY_TOK = 339,
     UNUSED_TTY_TOK = 340,
     IDLE_TIMEOUT_TOK = 341,
     IDLE_ACTION_TOK = 342,
     LOGOUT_TOK = 343,
     LOCK_TOK = 344,
     LOG_LEVEL_TOK = 345,
     DEBUG_TOK = 346,
     ERROR_TOK = 347,
     LOG_FACILITIES_TOK = 348,
     CONSOLE_TOK = 349,
     FILE_TOK = 350,
     SYSLOG_TOK = 351,
     MOUSE_CURSOR_TOK = 352,
     ANUM_T = 353,
     QUOTSTR_T = 354,
     COLOR_T = 355
   };
#endif
/* Tokens.  */
#define SCREENSAVER_TOK 258
#define SCRSVRS_DIR_TOK 259
#define SCRSVR_TIMEOUT_TOK 260
#define SCRN_POWER_TOK 261
#define XSESSION_DIR_TOK 262
#define TXTSESSION_DIR_TOK 263
#define XINIT_TOK 264
#define SHUTDOWN_TOK 265
#define TTY_TOK 266
#define THEMES_DIR_TOK 267
#define X_SERVER_TOK 268
#define DFB_INTERFACE_TOK 269
#define RESET_CONSOLE_TOK 270
#define X_ARGS_TOK 271
#define TEMP_FILES_DIR_TOK 272
#define THEME_TOK 273
#define WINDOW_TOK 274
#define RAND_TOK 275
#define CLEAR_BACKGROUND_TOK 276
#define LOCK_SESSIONS_TOK 277
#define NULL_TOK 278
#define DEFAULT_TXT_COL_TOK 279
#define DEFAULT_CUR_COL_TOK 280
#define OTHER_TXT_COL_TOK 281
#define BG_TOK 282
#define FONT_TOK 283
#define BUTTON_OPAC_TOK 284
#define WIN_OP_TOK 285
#define SEL_WIN_OP_TOK 286
#define THEME_RES_TOK 287
#define EVERYONE_TOK 288
#define ONLY_ROOT_TOK 289
#define NO_ONE_TOK 290
#define WPOLL_TIME_TOK 291
#define WTEXT_COLOR_TOK 292
#define WCURSOR_COLOR_TOK 293
#define WINDOW_LINK_TOK 294
#define WTYPE_TOK 295
#define WWIDTH_TOK 296
#define WHEIGHT_TOK 297
#define WCOMMAND_TOK 298
#define WCONTENT_TOK 299
#define WTEXT_SIZE_TOK 300
#define WTEXT_TINY_TOK 301
#define WTEXT_SMALLER_TOK 302
#define WTEXT_SMALL_TOK 303
#define WTEXT_MEDIUM_TOK 304
#define WTEXT_LARGE_TOK 305
#define WTEXT_ORIENTATION 306
#define WTEXT_LEFT_TOK 307
#define WTEXT_CENTER_TOK 308
#define WTEXT_RIGHT_TOK 309
#define YES_TOK 310
#define NO_TOK 311
#define AUTOLOGIN_TOK 312
#define USERNAME_TOK 313
#define PASSWORD_TOK 314
#define SESSION_TOK 315
#define RELOGIN_TOK 316
#define LAST_SESSION_TOK 317
#define SLEEP_TOK 318
#define NEXT_TTY_TOK 319
#define PREV_TTY_TOK 320
#define POWEROFF_TOK 321
#define REBOOT_TOK 322
#define KILL_TOK 323
#define TEXT_MODE_TOK 324
#define MENU_KEY_TOK 325
#define WIN_KEY_TOK 326
#define ALT_KEY_TOK 327
#define CTRL_KEY_TOK 328
#define KEYBINDINGS_TOK 329
#define USER_TOK 330
#define LAST_USER_POLICY_TOK 331
#define LAST_SESSION_POLICY_TOK 332
#define GLOBAL_TOK 333
#define NONE_TOK 334
#define PRE_GUI_TOK 335
#define POST_GUI_TOK 336
#define X_SERVER_OFFSET_TOK 337
#define X_SERVER_TTY_TOK 338
#define QINGY_TTY_TOK 339
#define UNUSED_TTY_TOK 340
#define IDLE_TIMEOUT_TOK 341
#define IDLE_ACTION_TOK 342
#define LOGOUT_TOK 343
#define LOCK_TOK 344
#define LOG_LEVEL_TOK 345
#define DEBUG_TOK 346
#define ERROR_TOK 347
#define LOG_FACILITIES_TOK 348
#define CONSOLE_TOK 349
#define FILE_TOK 350
#define SYSLOG_TOK 351
#define MOUSE_CURSOR_TOK 352
#define ANUM_T 353
#define QUOTSTR_T 354
#define COLOR_T 355




/* Copy the first part of user declarations.  */
#line 1 "parse_settings.y"

/*******************************************************************************/
/* parse_settings.y - Qingy theme and settings files parser 		               */
/*        								                                                     */
/*  Copyright (C) 2004 Paolo Gianrossi, (C) 2005-2006 Michele Noberasco        */
/*  All rights reserved                                                        */
/*  by Paolo Gianrossi   <paolino.gnu@disi.unige.it>                           */
/*     Michele Noberasco <michele.noberasco@tiscali.it>                        */
/* 									                                                           */
/* This program is free software; you can redistribute it and/or 	             */
/* modify  under the terms of the GNU General Public License as 	             */
/* published by the Free Software Foundation; either version 2, or (at 	       */
/* your option) any later version.					                                   */
/* 									                                                           */
/* This program is distributed in the hope that it will be useful, but 	       */
/* WITHOUT ANY WARRANTY; without even the implied warranty of 		             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 	         */
/* General Public License for more details.				                             */
/* 									                                                           */
/* You should have received a copy of the GNU General Public License 	         */
/* along with GNU Emacs; see the file COPYING.  If not, write to the 	         */
/* Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.	         */
/*******************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <stdio.h>

#include "memmgmt.h"
#include "load_settings.h"
#include "logger.h"
#include "misc.h"
#include "keybindings.h"
  
#define YYERROR_VERBOSE
#define TTY_CHECK_COND    if (!intended_tty || intended_tty == current_tty)
#define SSAVER_CHECK_COND if (ssaver_is_set) { erase_options(); ssaver_is_set = 0; }
  
extern FILE* yyin;
extern int yylex();
extern int in_theme;
static int in_window               = 0;
static int clear_background_is_set = 0;
static int intended_tty            = 0;
static int ssaver_is_set           = 0;
static int set_theme_result;

/* key bindings vars */
static actions   action;

static window_t wind =
  {
		0,
    0,
    0,
    0,
    0,
    0,
    LARGE,
    LEFT,
    &default_text_color,
    &default_cursor_color,
    UNKNOWN,
    NULL,
    NULL,
    NULL,
    NULL,
		NULL
  };

static cursor_t curs =
  {
		1,
    NULL,
		0,
		0,
		0,
		NULL
  };



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* Enabling the token table.  */
#ifndef YYTOKEN_TABLE
# define YYTOKEN_TABLE 0
#endif

#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 87 "parse_settings.y"
{
  int ival;
  char* str;
  unsigned char color[4];
}
/* Line 187 of yacc.c.  */
#line 387 "parse_settings.c"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 216 of yacc.c.  */
#line 400 "parse_settings.c"

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#elif (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
typedef signed char yytype_int8;
#else
typedef short int yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(msgid) dgettext ("bison-runtime", msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(msgid) msgid
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(e) ((void) (e))
#else
# define YYUSE(e) /* empty */
#endif

/* Identity function, used to suppress warnings about constant conditions.  */
#ifndef lint
# define YYID(n) (n)
#else
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static int
YYID (int i)
#else
static int
YYID (i)
    int i;
#endif
{
  return i;
}
#endif

#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#     ifndef _STDLIB_H
#      define _STDLIB_H 1
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (YYID (0))
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined _STDLIB_H \
       && ! ((defined YYMALLOC || defined malloc) \
	     && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef _STDLIB_H
#    define _STDLIB_H 1
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
	 || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  YYSIZE_T yyi;				\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (YYID (0))
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (YYID (0))

#endif

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  2
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   490

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  108
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  60
/* YYNRULES -- Number of rules.  */
#define YYNRULES  198
/* YYNRULES -- Number of states.  */
#define YYNSTATES  374

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   355

#define YYTRANSLATE(YYX)						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,   104,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,   101,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,   106,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     105,   107,     2,   102,     2,   103,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,    99,   100
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const yytype_uint16 yyprhs[] =
{
       0,     0,     3,     4,     7,    10,    13,    16,    19,    22,
      25,    28,    31,    34,    37,    40,    43,    46,    49,    52,
      55,    58,    61,    64,    67,    70,    73,    76,    79,    82,
      85,    88,    91,    96,   101,   102,   110,   111,   114,   117,
     120,   123,   126,   129,   132,   135,   138,   141,   144,   147,
     150,   153,   156,   159,   162,   165,   168,   171,   174,   177,
     180,   183,   186,   189,   192,   197,   202,   205,   210,   212,
     215,   218,   223,   228,   232,   236,   240,   244,   248,   252,
     256,   260,   264,   268,   270,   272,   274,   278,   280,   284,
     286,   288,   290,   292,   294,   296,   300,   304,   308,   312,
     316,   320,   324,   328,   332,   336,   339,   344,   346,   350,
     354,   358,   362,   366,   370,   374,   378,   382,   386,   390,
     394,   398,   402,   406,   410,   414,   418,   422,   426,   430,
     434,   438,   442,   447,   448,   451,   454,   457,   462,   467,
     470,   473,   477,   481,   487,   493,   497,   507,   511,   521,
     525,   535,   541,   547,   551,   555,   559,   563,   567,   572,
     573,   578,   580,   582,   584,   586,   588,   590,   592,   594,
     599,   601,   604,   608,   612,   616,   620,   624,   628,   632,
     636,   640,   644,   648,   650,   652,   654,   656,   658,   660,
     662,   664,   666,   668,   670,   672,   676,   686,   690
};

/* YYRHS -- A `-1'-separated list of the rules' RHS.  */
static const yytype_int16 yyrhs[] =
{
     109,     0,    -1,    -1,   109,   110,    -1,   109,   146,    -1,
     109,   147,    -1,   109,   128,    -1,   109,   129,    -1,   109,
     130,    -1,   109,   131,    -1,   109,   132,    -1,   109,   133,
      -1,   109,   134,    -1,   109,   135,    -1,   109,   143,    -1,
     109,   144,    -1,   109,   136,    -1,   109,   118,    -1,   109,
     119,    -1,   109,   138,    -1,   109,   139,    -1,   109,   140,
      -1,   109,   141,    -1,   109,   142,    -1,   109,   148,    -1,
     109,   149,    -1,   109,   120,    -1,   109,   127,    -1,   109,
     150,    -1,   109,   145,    -1,   109,   161,    -1,   109,   158,
      -1,   109,    21,   101,    55,    -1,   109,    21,   101,    56,
      -1,    -1,    11,   101,    98,   111,   102,   112,   103,    -1,
      -1,   112,   146,    -1,   112,   147,    -1,   112,   128,    -1,
     112,   129,    -1,   112,   130,    -1,   112,   131,    -1,   112,
     132,    -1,   112,   133,    -1,   112,   134,    -1,   112,   135,
      -1,   112,   143,    -1,   112,   144,    -1,   112,   136,    -1,
     112,   118,    -1,   112,   119,    -1,   112,   138,    -1,   112,
     139,    -1,   112,   140,    -1,   112,   141,    -1,   112,   142,
      -1,   112,   148,    -1,   112,   149,    -1,   112,   121,    -1,
     112,   127,    -1,   112,   150,    -1,   112,   145,    -1,   112,
     161,    -1,   112,    21,   101,    55,    -1,   112,    21,   101,
      56,    -1,   112,   113,    -1,    57,   102,   114,   103,    -1,
     115,    -1,   114,   116,    -1,   114,   117,    -1,   114,    61,
     101,    55,    -1,   114,    61,   101,    56,    -1,    58,   101,
      99,    -1,    59,   101,    99,    -1,    60,   101,    99,    -1,
      60,   101,    62,    -1,    14,   101,    99,    -1,    15,   101,
      99,    -1,    90,   101,   122,    -1,    93,   101,   123,    -1,
      90,   101,   122,    -1,    93,   101,   124,    -1,    91,    -1,
      92,    -1,   125,    -1,   125,   104,   123,    -1,   126,    -1,
     126,   104,   124,    -1,    94,    -1,    95,    -1,    96,    -1,
      94,    -1,    95,    -1,    96,    -1,    63,   101,    99,    -1,
      22,   101,    55,    -1,    22,   101,    56,    -1,     5,   101,
      98,    -1,     6,   101,    98,    -1,     4,   101,    99,    -1,
      12,   101,    99,    -1,    17,   101,    99,    -1,    80,   101,
      99,    -1,    81,   101,    99,    -1,     3,    99,    -1,     3,
      99,   101,   137,    -1,    99,    -1,   137,   104,    99,    -1,
       7,   101,    99,    -1,     8,   101,    99,    -1,     9,   101,
      99,    -1,    13,   101,    99,    -1,    16,   101,    99,    -1,
      82,   101,    98,    -1,    83,   101,    84,    -1,    83,   101,
      85,    -1,    10,   101,    33,    -1,    10,   101,    34,    -1,
      10,   101,    35,    -1,    76,   101,    78,    -1,    76,   101,
      11,    -1,    76,   101,    79,    -1,    77,   101,    75,    -1,
      77,   101,    11,    -1,    77,   101,    79,    -1,    86,   101,
      98,    -1,    87,   101,    88,    -1,    87,   101,    89,    -1,
      87,   101,    79,    -1,    18,   101,    20,    -1,    18,   101,
      99,    -1,    18,   102,   151,   103,    -1,    -1,   151,   156,
      -1,   151,   157,    -1,   151,   154,    -1,   151,    21,   101,
      55,    -1,   151,    21,   101,    56,    -1,   151,   155,    -1,
     151,   152,    -1,    97,   101,    55,    -1,    97,   101,    56,
      -1,    97,   101,   102,   153,   103,    -1,    99,   104,    98,
     104,    98,    -1,    24,   101,   100,    -1,    24,   101,    98,
     104,    98,   104,    98,   104,    98,    -1,    25,   101,   100,
      -1,    25,   101,    98,   104,    98,   104,    98,   104,    98,
      -1,    26,   101,   100,    -1,    26,   101,    98,   104,    98,
     104,    98,   104,    98,    -1,    32,   101,    98,   105,    98,
      -1,    32,   101,    98,   106,    98,    -1,    27,   101,    99,
      -1,    28,   101,    99,    -1,    29,   101,    98,    -1,    30,
     101,    98,    -1,    31,   101,    98,    -1,    74,   102,   159,
     103,    -1,    -1,   159,   160,   101,    99,    -1,    63,    -1,
      64,    -1,    65,    -1,    66,    -1,    67,    -1,     3,    -1,
      68,    -1,    69,    -1,    19,   102,   162,   103,    -1,   163,
      -1,   162,   163,    -1,   105,   101,    98,    -1,   107,   101,
      98,    -1,    40,   101,    99,    -1,    41,   101,    98,    -1,
      42,   101,    98,    -1,    43,   101,   164,    -1,    44,   101,
      99,    -1,    39,   101,    99,    -1,    36,   101,    98,    -1,
      51,   101,   165,    -1,    45,   101,   166,    -1,   167,    -1,
     152,    -1,    23,    -1,    99,    -1,    52,    -1,    53,    -1,
      54,    -1,    46,    -1,    47,    -1,    48,    -1,    49,    -1,
      50,    -1,    37,   101,   100,    -1,    37,   101,    98,   104,
      98,   104,    98,   104,    98,    -1,    38,   101,   100,    -1,
      38,   101,    98,   104,    98,   104,    98,   104,    98,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   168,   168,   169,   170,   171,   172,   173,   174,   175,
     176,   177,   178,   179,   180,   181,   182,   183,   184,   185,
     186,   187,   188,   189,   190,   191,   192,   193,   194,   195,
     196,   197,   198,   199,   203,   203,   206,   207,   208,   209,
     210,   211,   212,   213,   214,   215,   216,   217,   218,   219,
     220,   221,   222,   223,   224,   225,   226,   227,   228,   229,
     230,   231,   232,   233,   234,   235,   236,   239,   241,   242,
     243,   244,   245,   248,   253,   258,   259,   261,   267,   274,
     275,   278,   279,   282,   283,   286,   287,   290,   291,   294,
     295,   296,   299,   300,   301,   305,   312,   313,   317,   344,
     371,   378,   385,   392,   399,   406,   407,   410,   411,   415,
     423,   430,   437,   444,   451,   458,   463,   471,   476,   481,
     489,   494,   499,   507,   512,   517,   525,   532,   537,   542,
     550,   551,   552,   556,   557,   558,   559,   560,   561,   562,
     563,   567,   579,   591,   595,   610,   618,   626,   634,   642,
     650,   661,   668,   678,   679,   683,   684,   685,   689,   695,
     696,   703,   704,   705,   706,   707,   708,   709,   710,   714,
     730,   730,   732,   733,   734,   735,   736,   737,   738,   739,
     740,   741,   742,   743,   744,   747,   748,   751,   752,   753,
     756,   757,   758,   759,   760,   764,   773,   782,   791
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "SCREENSAVER_TOK", "SCRSVRS_DIR_TOK",
  "SCRSVR_TIMEOUT_TOK", "SCRN_POWER_TOK", "XSESSION_DIR_TOK",
  "TXTSESSION_DIR_TOK", "XINIT_TOK", "SHUTDOWN_TOK", "TTY_TOK",
  "THEMES_DIR_TOK", "X_SERVER_TOK", "DFB_INTERFACE_TOK",
  "RESET_CONSOLE_TOK", "X_ARGS_TOK", "TEMP_FILES_DIR_TOK", "THEME_TOK",
  "WINDOW_TOK", "RAND_TOK", "CLEAR_BACKGROUND_TOK", "LOCK_SESSIONS_TOK",
  "NULL_TOK", "DEFAULT_TXT_COL_TOK", "DEFAULT_CUR_COL_TOK",
  "OTHER_TXT_COL_TOK", "BG_TOK", "FONT_TOK", "BUTTON_OPAC_TOK",
  "WIN_OP_TOK", "SEL_WIN_OP_TOK", "THEME_RES_TOK", "EVERYONE_TOK",
  "ONLY_ROOT_TOK", "NO_ONE_TOK", "WPOLL_TIME_TOK", "WTEXT_COLOR_TOK",
  "WCURSOR_COLOR_TOK", "WINDOW_LINK_TOK", "WTYPE_TOK", "WWIDTH_TOK",
  "WHEIGHT_TOK", "WCOMMAND_TOK", "WCONTENT_TOK", "WTEXT_SIZE_TOK",
  "WTEXT_TINY_TOK", "WTEXT_SMALLER_TOK", "WTEXT_SMALL_TOK",
  "WTEXT_MEDIUM_TOK", "WTEXT_LARGE_TOK", "WTEXT_ORIENTATION",
  "WTEXT_LEFT_TOK", "WTEXT_CENTER_TOK", "WTEXT_RIGHT_TOK", "YES_TOK",
  "NO_TOK", "AUTOLOGIN_TOK", "USERNAME_TOK", "PASSWORD_TOK", "SESSION_TOK",
  "RELOGIN_TOK", "LAST_SESSION_TOK", "SLEEP_TOK", "NEXT_TTY_TOK",
  "PREV_TTY_TOK", "POWEROFF_TOK", "REBOOT_TOK", "KILL_TOK",
  "TEXT_MODE_TOK", "MENU_KEY_TOK", "WIN_KEY_TOK", "ALT_KEY_TOK",
  "CTRL_KEY_TOK", "KEYBINDINGS_TOK", "USER_TOK", "LAST_USER_POLICY_TOK",
  "LAST_SESSION_POLICY_TOK", "GLOBAL_TOK", "NONE_TOK", "PRE_GUI_TOK",
  "POST_GUI_TOK", "X_SERVER_OFFSET_TOK", "X_SERVER_TTY_TOK",
  "QINGY_TTY_TOK", "UNUSED_TTY_TOK", "IDLE_TIMEOUT_TOK", "IDLE_ACTION_TOK",
  "LOGOUT_TOK", "LOCK_TOK", "LOG_LEVEL_TOK", "DEBUG_TOK", "ERROR_TOK",
  "LOG_FACILITIES_TOK", "CONSOLE_TOK", "FILE_TOK", "SYSLOG_TOK",
  "MOUSE_CURSOR_TOK", "ANUM_T", "QUOTSTR_T", "COLOR_T", "'='", "'{'",
  "'}'", "','", "'x'", "'X'", "'y'", "$accept", "config", "tty_specific",
  "@1", "config_tty", "autologin", "config_autologin", "username",
  "password", "session", "dfb_interface", "reset_console", "logging",
  "logging_tty", "loglevels", "logfacilities", "logfacilities_tty",
  "logfacility", "logfacility_tty", "sleep", "lck_sess", "scrsvr_timeout",
  "scrpvr_timeout", "scrsvrs_dir", "themes_dir", "temp_dir", "pre_gui",
  "post_gui", "ssav", "scrsvr_with_options", "xsessdir", "txtsessdir",
  "xinit", "x_server", "x_args", "x_serv_offset", "x_serv_tty", "shutdown",
  "last_user", "last_session", "idle_timeout", "idle_action", "theme",
  "themedefn", "mousecursorprop", "cursordefn", "colorprop",
  "resolutionprop", "strprop", "anumprop", "keybindings",
  "keybindingsdefns", "actiondefns", "window", "windefns", "windefn",
  "buttoncommand", "textorientation", "wintextsize", "wincolorprop", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310,   311,   312,   313,   314,
     315,   316,   317,   318,   319,   320,   321,   322,   323,   324,
     325,   326,   327,   328,   329,   330,   331,   332,   333,   334,
     335,   336,   337,   338,   339,   340,   341,   342,   343,   344,
     345,   346,   347,   348,   349,   350,   351,   352,   353,   354,
     355,    61,   123,   125,    44,   120,    88,   121
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,   108,   109,   109,   109,   109,   109,   109,   109,   109,
     109,   109,   109,   109,   109,   109,   109,   109,   109,   109,
     109,   109,   109,   109,   109,   109,   109,   109,   109,   109,
     109,   109,   109,   109,   111,   110,   112,   112,   112,   112,
     112,   112,   112,   112,   112,   112,   112,   112,   112,   112,
     112,   112,   112,   112,   112,   112,   112,   112,   112,   112,
     112,   112,   112,   112,   112,   112,   112,   113,   114,   114,
     114,   114,   114,   115,   116,   117,   117,   118,   119,   120,
     120,   121,   121,   122,   122,   123,   123,   124,   124,   125,
     125,   125,   126,   126,   126,   127,   128,   128,   129,   130,
     131,   132,   133,   134,   135,   136,   136,   137,   137,   138,
     139,   140,   141,   142,   143,   144,   144,   145,   145,   145,
     146,   146,   146,   147,   147,   147,   148,   149,   149,   149,
     150,   150,   150,   151,   151,   151,   151,   151,   151,   151,
     151,   152,   152,   152,   153,   154,   154,   154,   154,   154,
     154,   155,   155,   156,   156,   157,   157,   157,   158,   159,
     159,   160,   160,   160,   160,   160,   160,   160,   160,   161,
     162,   162,   163,   163,   163,   163,   163,   163,   163,   163,
     163,   163,   163,   163,   163,   164,   164,   165,   165,   165,
     166,   166,   166,   166,   166,   167,   167,   167,   167
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     0,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     4,     4,     0,     7,     0,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     4,     4,     2,     4,     1,     2,
       2,     4,     4,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     1,     1,     1,     3,     1,     3,     1,
       1,     1,     1,     1,     1,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     2,     4,     1,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     4,     0,     2,     2,     2,     4,     4,     2,
       2,     3,     3,     5,     5,     3,     9,     3,     9,     3,
       9,     5,     5,     3,     3,     3,     3,     3,     4,     0,
       4,     1,     1,     1,     1,     1,     1,     1,     1,     4,
       1,     2,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     3,     9,     3,     9
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       2,     0,     1,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     3,    17,    18,    26,    27,     6,
       7,     8,     9,    10,    11,    12,    13,    16,    19,    20,
      21,    22,    23,    14,    15,    29,     4,     5,    24,    25,
      28,    31,    30,   105,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   133,
       0,     0,     0,     0,   159,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   100,    98,    99,   109,
     110,   111,   117,   118,   119,    34,   101,   112,    77,    78,
     113,   102,   130,   131,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   184,
       0,   170,   183,    32,    33,    96,    97,    95,     0,   121,
     120,   122,   124,   123,   125,   103,   104,   114,   115,   116,
     126,   129,   127,   128,    83,    84,    79,    89,    90,    91,
      80,    85,   107,   106,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   132,   140,   136,   139,   134,
     135,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   169,   171,   166,   161,   162,
     163,   164,   165,   167,   168,   158,     0,     0,     0,    36,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     180,     0,   195,     0,   197,   179,   174,   175,   176,   185,
     186,   177,   178,   190,   191,   192,   193,   194,   182,   187,
     188,   189,   181,   141,   142,     0,   172,   173,     0,    86,
     108,     0,   137,   138,     0,   145,     0,   147,     0,   149,
     153,   154,   155,   156,   157,     0,     0,     0,     0,     0,
     160,     0,     0,     0,     0,    35,    66,    50,    51,    59,
      60,    39,    40,    41,    42,    43,    44,    45,    46,    49,
      52,    53,    54,    55,    56,    47,    48,    62,    37,    38,
      57,    58,    61,    63,     0,     0,     0,     0,     0,     0,
       0,     0,   143,     0,     0,     0,     0,     0,     0,     0,
     151,   152,     0,     0,     0,    64,    65,     0,     0,    68,
      81,    92,    93,    94,    82,    87,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,    67,    69,    70,     0,
       0,     0,     0,     0,     0,   144,    73,     0,     0,     0,
      88,     0,     0,     0,   196,   198,    74,    76,    75,    71,
      72,   146,   148,   150
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
      -1,     1,    34,   164,   251,   276,   328,   329,   347,   348,
      35,    36,    37,   279,   156,   160,   334,   161,   335,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,   163,
      48,    49,    50,    51,    52,    53,    54,    55,    56,    57,
      58,    59,    60,   114,   129,   269,   177,   178,   179,   180,
      61,   138,   206,    62,   130,   131,   231,   242,   238,   132
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -92
static const yytype_int16 yypact[] =
{
     -92,    98,   -92,   -91,   -66,   -46,   -40,   -30,   -19,   -15,
      29,    70,    72,    81,    82,    85,    86,    88,   -72,   -58,
      89,    91,    92,    93,    95,    96,   100,   102,   104,   105,
     106,   107,   108,   111,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   112,    48,    24,   101,    99,   115,   116,
      -1,   118,   120,   122,   123,   124,   125,   126,     0,   -92,
     113,    11,    20,   127,   -92,    10,     6,   128,   129,   119,
      75,   131,   -52,    71,   -56,   132,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,    21,   133,   134,   135,   136,   137,
     138,   139,   140,   141,   142,   143,   144,   145,   146,   -92,
      97,   -92,   -92,   -92,   -92,   -92,   -92,   -92,    28,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   147,   -92,   148,   109,   149,   152,   153,   154,   155,
     156,   157,   158,   159,   160,   -92,   -92,   -92,   -92,   -92,
     -92,   150,   -57,   -28,   163,   164,   151,   166,    33,   167,
      79,     5,   -33,   169,   170,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   168,   -56,   171,   -92,
     110,    23,    45,    46,   172,   173,   175,   176,   177,   178,
     -92,   161,   -92,   174,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   180,   -92,   -92,   181,   -92,
     -92,    -3,   -92,   -92,   179,   -92,   182,   -92,   183,   -92,
     -92,   -92,   -92,   -92,   -92,    62,   184,   186,   185,   130,
     -92,   187,   188,   190,   191,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92,   195,   196,   197,   198,   199,   194,
     200,   201,   -92,   114,   219,    71,   -32,   202,   203,   204,
     -92,   -92,   205,   207,   206,   -92,   -92,   208,   -35,   -92,
     -92,   -92,   -92,   -92,   -92,   209,   213,   214,   216,   211,
     212,   220,   218,   221,   222,   223,   -92,   -92,   -92,   -32,
     215,   217,   224,   227,   228,   -92,   -92,   230,   -34,   121,
     -92,   229,   232,   233,   -92,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   -92
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
     -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,   -92,
     -21,    30,   -92,   -92,   -83,    78,   -49,   -92,   -92,    50,
      51,    69,    83,    84,    87,    90,    94,   103,   117,   -92,
     162,   165,   189,   192,   193,   210,   225,   226,   231,   234,
     235,   236,   237,   -92,   238,   -92,   -92,   -92,   -92,   -92,
     -92,   -92,   -92,   239,   -92,   240,   -92,   -92,   -92,   -92
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const yytype_uint16 yytable[] =
{
       3,     4,     5,     6,     7,     8,     9,    10,    63,    12,
      13,    14,    15,    16,    17,    18,    19,   142,   271,    21,
     112,   139,   243,   244,   343,   344,   345,   151,   367,    78,
      79,   197,   102,   103,   104,    64,   152,   153,   157,   158,
     159,   221,   165,   222,    80,   166,   167,   168,   169,   170,
     171,   172,   173,   174,   272,    65,   229,   239,   240,   241,
      22,    66,   331,   332,   333,   368,   133,   134,   346,   245,
     223,    67,   224,    24,    25,   135,   136,    26,    27,    28,
      29,   143,    68,    30,    31,   144,    69,   273,   140,   141,
     274,   198,   199,   200,   201,   202,   203,   204,     2,   113,
     275,     3,     4,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,    18,    19,   126,    20,
      21,   254,    97,   255,   175,   233,   234,   235,   236,   237,
      70,   205,   230,   115,   116,   117,   118,   119,   120,   121,
     122,   123,   124,   256,   258,   257,   259,    96,   125,   115,
     116,   117,   118,   119,   120,   121,   122,   123,   124,   148,
     149,    22,   154,   155,   125,   252,   253,   307,   308,   325,
     326,    71,    23,    72,    24,    25,   369,   370,    26,    27,
      28,    29,    73,    74,    30,    31,    75,    76,    32,    77,
      81,    33,    82,    83,   126,    84,    85,    86,    99,    98,
     195,    87,   127,    88,   128,    89,    90,    91,    92,    93,
     126,   209,    94,    95,   100,   101,   105,   147,   127,   106,
     128,   107,   108,   109,   110,   111,   137,   145,   146,   150,
     277,   162,   330,   312,   181,   182,   183,   184,   185,   186,
     187,   188,   189,   190,   191,   192,   193,   194,   220,   227,
     210,   207,   208,   211,   212,   213,   214,   215,   216,   217,
     218,   219,   225,   226,   228,   266,   232,   246,   247,   248,
     250,   260,   261,   262,   263,   264,   265,   327,   267,   268,
     270,   278,   309,   304,   310,   249,   305,   306,   313,   311,
     314,   315,   316,   317,   318,   319,   320,   321,   322,   324,
     360,   280,   281,   339,   323,   340,   336,   337,   338,   342,
     341,   350,   351,   349,   352,   353,   354,   356,   355,   361,
     282,   362,   357,   358,   359,   364,   365,   371,   363,   366,
     372,   373,     0,     0,   283,   284,     0,     0,   285,     0,
       0,   286,     0,     0,     0,   287,     0,     0,     0,     0,
       0,     0,   176,     0,   288,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,   289,     0,
     196,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   290,     0,     0,   291,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     292,     0,     0,   293,   294,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   295,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   296,   297,     0,     0,
       0,     0,   298,     0,     0,   299,   300,   301,   302,     0,
     303
};

static const yytype_int16 yycheck[] =
{
       3,     4,     5,     6,     7,     8,     9,    10,    99,    12,
      13,    14,    15,    16,    17,    18,    19,    11,    21,    22,
      20,    11,    55,    56,    59,    60,    61,    79,    62,   101,
     102,     3,    33,    34,    35,   101,    88,    89,    94,    95,
      96,    98,    21,   100,   102,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    57,   101,    23,    52,    53,    54,
      63,   101,    94,    95,    96,    99,    55,    56,   103,   102,
      98,   101,   100,    76,    77,    55,    56,    80,    81,    82,
      83,    75,   101,    86,    87,    79,   101,    90,    78,    79,
      93,    63,    64,    65,    66,    67,    68,    69,     0,    99,
     103,     3,     4,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,    18,    19,    97,    21,
      22,    98,    98,   100,   103,    46,    47,    48,    49,    50,
     101,   103,    99,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    98,    98,   100,   100,    99,    51,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    84,
      85,    63,    91,    92,    51,    55,    56,   105,   106,    55,
      56,   101,    74,   101,    76,    77,    55,    56,    80,    81,
      82,    83,   101,   101,    86,    87,   101,   101,    90,   101,
     101,    93,   101,   101,    97,   102,   101,   101,    99,    98,
     103,   101,   105,   101,   107,   101,   101,   101,   101,   101,
      97,   102,   101,   101,    99,    99,    98,    98,   105,    99,
     107,    99,    99,    99,    99,    99,    99,    99,    99,    98,
     251,    99,   315,   103,   101,   101,   101,   101,   101,   101,
     101,   101,   101,   101,   101,   101,   101,   101,    98,    98,
     101,   104,   104,   101,   101,   101,   101,   101,   101,   101,
     101,   101,    99,    99,    98,   104,    99,    98,    98,   101,
      99,    99,    99,    98,    98,    98,    98,    58,   104,    99,
      99,   251,    98,   104,    98,   207,   104,   104,   101,   104,
     102,   101,   101,    98,    98,    98,    98,    98,   104,    98,
     349,   251,   251,    98,   104,    98,   104,   104,   104,   101,
     104,    98,    98,   104,    98,   104,   104,    99,    98,   104,
     251,   104,   101,   101,   101,    98,    98,    98,   104,    99,
      98,    98,    -1,    -1,   251,   251,    -1,    -1,   251,    -1,
      -1,   251,    -1,    -1,    -1,   251,    -1,    -1,    -1,    -1,
      -1,    -1,   114,    -1,   251,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   251,    -1,
     130,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   251,    -1,    -1,   251,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
     251,    -1,    -1,   251,   251,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   251,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,   251,   251,    -1,    -1,
      -1,    -1,   251,    -1,    -1,   251,   251,   251,   251,    -1,
     251
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,   109,     0,     3,     4,     5,     6,     7,     8,     9,
      10,    11,    12,    13,    14,    15,    16,    17,    18,    19,
      21,    22,    63,    74,    76,    77,    80,    81,    82,    83,
      86,    87,    90,    93,   110,   118,   119,   120,   127,   128,
     129,   130,   131,   132,   133,   134,   135,   136,   138,   139,
     140,   141,   142,   143,   144,   145,   146,   147,   148,   149,
     150,   158,   161,    99,   101,   101,   101,   101,   101,   101,
     101,   101,   101,   101,   101,   101,   101,   101,   101,   102,
     102,   101,   101,   101,   102,   101,   101,   101,   101,   101,
     101,   101,   101,   101,   101,   101,    99,    98,    98,    99,
      99,    99,    33,    34,    35,    98,    99,    99,    99,    99,
      99,    99,    20,    99,   151,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    51,    97,   105,   107,   152,
     162,   163,   167,    55,    56,    55,    56,    99,   159,    11,
      78,    79,    11,    75,    79,    99,    99,    98,    84,    85,
      98,    79,    88,    89,    91,    92,   122,    94,    95,    96,
     123,   125,    99,   137,   111,    21,    24,    25,    26,    27,
      28,    29,    30,    31,    32,   103,   152,   154,   155,   156,
     157,   101,   101,   101,   101,   101,   101,   101,   101,   101,
     101,   101,   101,   101,   101,   103,   163,     3,    63,    64,
      65,    66,    67,    68,    69,   103,   160,   104,   104,   102,
     101,   101,   101,   101,   101,   101,   101,   101,   101,   101,
      98,    98,   100,    98,   100,    99,    99,    98,    98,    23,
      99,   164,    99,    46,    47,    48,    49,    50,   166,    52,
      53,    54,   165,    55,    56,   102,    98,    98,   101,   123,
      99,   112,    55,    56,    98,   100,    98,   100,    98,   100,
      99,    99,    98,    98,    98,    98,   104,   104,    99,   153,
      99,    21,    57,    90,    93,   103,   113,   118,   119,   121,
     127,   128,   129,   130,   131,   132,   133,   134,   135,   136,
     138,   139,   140,   141,   142,   143,   144,   145,   146,   147,
     148,   149,   150,   161,   104,   104,   104,   105,   106,    98,
      98,   104,   103,   101,   102,   101,   101,    98,    98,    98,
      98,    98,   104,   104,    98,    55,    56,    58,   114,   115,
     122,    94,    95,    96,   124,   126,   104,   104,   104,    98,
      98,   104,   101,    59,    60,    61,   103,   116,   117,   104,
      98,    98,    98,   104,   104,    98,    99,   101,   101,   101,
     124,   104,   104,   104,    98,    98,    99,    62,    99,    55,
      56,    98,    98,    98
};

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrorlab


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK (1);						\
      goto yybackup;						\
    }								\
  else								\
    {								\
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;							\
    }								\
while (YYID (0))


#define YYTERROR	1
#define YYERRCODE	256


/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#define YYRHSLOC(Rhs, K) ((Rhs)[K])
#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)				\
    do									\
      if (YYID (N))                                                    \
	{								\
	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
	}								\
      else								\
	{								\
	  (Current).first_line   = (Current).last_line   =		\
	    YYRHSLOC (Rhs, 0).last_line;				\
	  (Current).first_column = (Current).last_column =		\
	    YYRHSLOC (Rhs, 0).last_column;				\
	}								\
    while (YYID (0))
#endif


/* YY_LOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

#ifndef YY_LOCATION_PRINT
# if YYLTYPE_IS_TRIVIAL
#  define YY_LOCATION_PRINT(File, Loc)			\
     fprintf (File, "%d.%d-%d.%d",			\
	      (Loc).first_line, (Loc).first_column,	\
	      (Loc).last_line,  (Loc).last_column)
# else
#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
# endif
#endif


/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (YYID (0))

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)			  \
do {									  \
  if (yydebug)								  \
    {									  \
      YYFPRINTF (stderr, "%s ", Title);					  \
      yy_symbol_print (stderr,						  \
		  Type, Value); \
      YYFPRINTF (stderr, "\n");						  \
    }									  \
} while (YYID (0))


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_value_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# else
  YYUSE (yyoutput);
# endif
  switch (yytype)
    {
      default:
	break;
    }
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (yytype < YYNTOKENS)
    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
#else
static void
yy_stack_print (bottom, top)
    yytype_int16 *bottom;
    yytype_int16 *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (YYID (0))


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
#else
static void
yy_reduce_print (yyvsp, yyrule)
    YYSTYPE *yyvsp;
    int yyrule;
#endif
{
  int yynrhs = yyr2[yyrule];
  int yyi;
  unsigned long int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
	     yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      fprintf (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
		       &(yyvsp[(yyi + 1) - (yynrhs)])
		       		       );
      fprintf (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (yyvsp, Rule); \
} while (YYID (0))

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static YYSIZE_T
yystrlen (const char *yystr)
#else
static YYSIZE_T
yystrlen (yystr)
    const char *yystr;
#endif
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static char *
yystpcpy (char *yydest, const char *yysrc)
#else
static char *
yystpcpy (yydest, yysrc)
    char *yydest;
    const char *yysrc;
#endif
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
	switch (*++yyp)
	  {
	  case '\'':
	  case ',':
	    goto do_not_strip_quotes;

	  case '\\':
	    if (*++yyp != '\\')
	      goto do_not_strip_quotes;
	    /* Fall through.  */
	  default:
	    if (yyres)
	      yyres[yyn] = *yyp;
	    yyn++;
	    break;

	  case '"':
	    if (yyres)
	      yyres[yyn] = '\0';
	    return yyn;
	  }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into YYRESULT an error message about the unexpected token
   YYCHAR while in state YYSTATE.  Return the number of bytes copied,
   including the terminating null byte.  If YYRESULT is null, do not
   copy anything; just return the number of bytes that would be
   copied.  As a special case, return 0 if an ordinary "syntax error"
   message will do.  Return YYSIZE_MAXIMUM if overflow occurs during
   size calculation.  */
static YYSIZE_T
yysyntax_error (char *yyresult, int yystate, int yychar)
{
  int yyn = yypact[yystate];

  if (! (YYPACT_NINF < yyn && yyn <= YYLAST))
    return 0;
  else
    {
      int yytype = YYTRANSLATE (yychar);
      YYSIZE_T yysize0 = yytnamerr (0, yytname[yytype]);
      YYSIZE_T yysize = yysize0;
      YYSIZE_T yysize1;
      int yysize_overflow = 0;
      enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
      char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
      int yyx;

# if 0
      /* This is so xgettext sees the translatable formats that are
	 constructed on the fly.  */
      YY_("syntax error, unexpected %s");
      YY_("syntax error, unexpected %s, expecting %s");
      YY_("syntax error, unexpected %s, expecting %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
# endif
      char *yyfmt;
      char const *yyf;
      static char const yyunexpected[] = "syntax error, unexpected %s";
      static char const yyexpecting[] = ", expecting %s";
      static char const yyor[] = " or %s";
      char yyformat[sizeof yyunexpected
		    + sizeof yyexpecting - 1
		    + ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
		       * (sizeof yyor - 1))];
      char const *yyprefix = yyexpecting;

      /* Start YYX at -YYN if negative to avoid negative indexes in
	 YYCHECK.  */
      int yyxbegin = yyn < 0 ? -yyn : 0;

      /* Stay within bounds of both yycheck and yytname.  */
      int yychecklim = YYLAST - yyn + 1;
      int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
      int yycount = 1;

      yyarg[0] = yytname[yytype];
      yyfmt = yystpcpy (yyformat, yyunexpected);

      for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	  {
	    if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
	      {
		yycount = 1;
		yysize = yysize0;
		yyformat[sizeof yyunexpected - 1] = '\0';
		break;
	      }
	    yyarg[yycount++] = yytname[yyx];
	    yysize1 = yysize + yytnamerr (0, yytname[yyx]);
	    yysize_overflow |= (yysize1 < yysize);
	    yysize = yysize1;
	    yyfmt = yystpcpy (yyfmt, yyprefix);
	    yyprefix = yyor;
	  }

      yyf = YY_(yyformat);
      yysize1 = yysize + yystrlen (yyf);
      yysize_overflow |= (yysize1 < yysize);
      yysize = yysize1;

      if (yysize_overflow)
	return YYSIZE_MAXIMUM;

      if (yyresult)
	{
	  /* Avoid sprintf, as that infringes on the user's name space.
	     Don't have undefined behavior even if the translation
	     produced a string with the wrong number of "%s"s.  */
	  char *yyp = yyresult;
	  int yyi = 0;
	  while ((*yyp = *yyf) != '\0')
	    {
	      if (*yyp == '%' && yyf[1] == 's' && yyi < yycount)
		{
		  yyp += yytnamerr (yyp, yyarg[yyi++]);
		  yyf += 2;
		}
	      else
		{
		  yyp++;
		  yyf++;
		}
	    }
	}
      return yysize;
    }
}
#endif /* YYERROR_VERBOSE */


/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yymsg, yytype, yyvaluep)
    const char *yymsg;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  YYUSE (yyvaluep);

  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  switch (yytype)
    {

      default:
	break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int yyparse (void *YYPARSE_PARAM);
#else
int yyparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The look-ahead symbol.  */
int yychar;

/* The semantic value of the look-ahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void *YYPARSE_PARAM)
#else
int
yyparse (YYPARSE_PARAM)
    void *YYPARSE_PARAM;
#endif
#else /* ! YYPARSE_PARAM */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  
  int yystate;
  int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Look-ahead token as an internal (translated) token number.  */
  int yytoken = 0;
#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  yytype_int16 yyssa[YYINITDEPTH];
  yytype_int16 *yyss = yyssa;
  yytype_int16 *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  YYSTYPE *yyvsp;



#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack.  Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	yytype_int16 *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow (YY_("memory exhausted"),
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	yytype_int16 *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyexhaustedlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     look-ahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to look-ahead token.  */
  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a look-ahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the look-ahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  yystate = yyn;
  *++yyvsp = yylval;

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 16:
#line 182 "parse_settings.y"
    { TTY_CHECK_COND ssaver_is_set = 1; }
    break;

  case 28:
#line 194 "parse_settings.y"
    { TTY_CHECK_COND got_theme=set_theme_result; }
    break;

  case 32:
#line 198 "parse_settings.y"
    { if (!clear_background_is_set) clear_background = 1; }
    break;

  case 33:
#line 199 "parse_settings.y"
    { if (!clear_background_is_set) clear_background = 0; }
    break;

  case 34:
#line 203 "parse_settings.y"
    { intended_tty = (yyvsp[(3) - (3)].ival); }
    break;

  case 35:
#line 203 "parse_settings.y"
    { intended_tty = 0; }
    break;

  case 49:
#line 219 "parse_settings.y"
    { TTY_CHECK_COND ssaver_is_set = 1; }
    break;

  case 61:
#line 231 "parse_settings.y"
    { TTY_CHECK_COND got_theme=set_theme_result; }
    break;

  case 64:
#line 234 "parse_settings.y"
    { TTY_CHECK_COND {if (!clear_background_is_set) clear_background = 1;} }
    break;

  case 65:
#line 235 "parse_settings.y"
    { TTY_CHECK_COND {if (!clear_background_is_set) clear_background = 0;} }
    break;

  case 66:
#line 236 "parse_settings.y"
    { TTY_CHECK_COND do_autologin=1;  }
    break;

  case 71:
#line 244 "parse_settings.y"
    { TTY_CHECK_COND auto_relogin = 1; }
    break;

  case 72:
#line 245 "parse_settings.y"
    { TTY_CHECK_COND auto_relogin = 0; }
    break;

  case 73:
#line 249 "parse_settings.y"
    {
	  TTY_CHECK_COND autologin_username = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 74:
#line 254 "parse_settings.y"
    {
	  TTY_CHECK_COND autologin_password = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 75:
#line 258 "parse_settings.y"
    { TTY_CHECK_COND autologin_session = strdup((yyvsp[(3) - (3)].str)); }
    break;

  case 76:
#line 259 "parse_settings.y"
    { TTY_CHECK_COND autologin_session = strdup("LAST"); }
    break;

  case 77:
#line 262 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'qingy_DirectFB' is not allowed in theme file.");
	  TTY_CHECK_COND { if (dfb_interface) free(dfb_interface); dfb_interface = strdup((yyvsp[(3) - (3)].str)); }
	}
    break;

  case 78:
#line 268 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'qingy_reset_console' is not allowed in theme file.");
	  TTY_CHECK_COND { if (reset_console_utility) free(reset_console_utility); reset_console_utility = strdup((yyvsp[(3) - (3)].str)); }
	}
    break;

  case 83:
#line 282 "parse_settings.y"
    { TTY_CHECK_COND max_loglevel = DEBUG; }
    break;

  case 84:
#line 283 "parse_settings.y"
    { TTY_CHECK_COND max_loglevel = ERROR; }
    break;

  case 89:
#line 294 "parse_settings.y"
    { TTY_CHECK_COND log_facilities |= LOG_TO_CONSOLE; }
    break;

  case 90:
#line 295 "parse_settings.y"
    { TTY_CHECK_COND log_facilities |= LOG_TO_FILE;    }
    break;

  case 91:
#line 296 "parse_settings.y"
    { TTY_CHECK_COND log_facilities |= LOG_TO_SYSLOG;  }
    break;

  case 92:
#line 299 "parse_settings.y"
    { TTY_CHECK_COND log_facilities_tty |= LOG_TO_CONSOLE; }
    break;

  case 93:
#line 300 "parse_settings.y"
    { TTY_CHECK_COND log_facilities_tty |= LOG_TO_FILE;    }
    break;

  case 94:
#line 301 "parse_settings.y"
    { TTY_CHECK_COND log_facilities_tty |= LOG_TO_SYSLOG;  }
    break;

  case 95:
#line 306 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'sleep' is not allowed in theme file.");
	  TTY_CHECK_COND { if (sleep_cmd) free(sleep_cmd); sleep_cmd = strdup((yyvsp[(3) - (3)].str)); }
	}
    break;

  case 96:
#line 312 "parse_settings.y"
    { TTY_CHECK_COND lock_sessions = 1; }
    break;

  case 97:
#line 313 "parse_settings.y"
    { TTY_CHECK_COND lock_sessions = 0; }
    break;

  case 98:
#line 318 "parse_settings.y"
    {
		if(in_theme) yyerror("Setting 'screensaver_timeout' is not allowed in theme file");
		TTY_CHECK_COND
		{
			if ((yyvsp[(3) - (3)].ival) < 0)
			{
				writelog(ERROR, "Invalid screen saver timeout: screensaver will be disabled.\n");
				use_screensaver     = 0;
				screensaver_timeout = 0;
			}
			else
			{
				use_screensaver     = 1;
				screensaver_timeout = (yyvsp[(3) - (3)].ival);
				WRITELOG(DEBUG, "You chose a screen saver timeout of %d minute%s", screensaver_timeout, (screensaver_timeout == 1) ? "" : "s");
				if ((yyvsp[(3) - (3)].ival) == 0)
				{
					use_screensaver = 0;
					writelog(DEBUG, ", thus disabling them");
				}
				writelog(DEBUG, ".\n");
			}
		}
	}
    break;

  case 99:
#line 345 "parse_settings.y"
    {
		if(in_theme) yyerror("Setting 'screen_powersaving_timeout' is not allowed in theme file");
		TTY_CHECK_COND
		{
			if ((yyvsp[(3) - (3)].ival) < 0)
			{
				writelog(ERROR, "Invalid screen power management timeout: feature will be disabled.\n");
				use_screen_power_management     = 0;
				screen_power_management_timeout = 0;
			}
			else
			{
				use_screen_power_management     = 1;
				screen_power_management_timeout = (yyvsp[(3) - (3)].ival);
				WRITELOG(DEBUG, "You chose a screen power management timeout of %d minute%s", screen_power_management_timeout, (screen_power_management_timeout == 1) ? "" : "s");
				if ((yyvsp[(3) - (3)].ival) == 0)
				{
					use_screen_power_management = 0;
					writelog(DEBUG, ", thus disabling the feature");
				}
				writelog(DEBUG, ".\n");
			}
		}
	}
    break;

  case 100:
#line 372 "parse_settings.y"
    {
		if(in_theme) yyerror("Setting 'screensavers_dir' is not allowed in theme file.");
		TTY_CHECK_COND screensavers_dir = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 101:
#line 379 "parse_settings.y"
    {
		if(in_theme) yyerror("Setting 'themes_dir' is not allowed in theme file.");
		TTY_CHECK_COND themes_dir = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 102:
#line 386 "parse_settings.y"
    {
		if(in_theme) yyerror("Setting 'temp_files_dir' is not allowed in theme file.");
		TTY_CHECK_COND { if (tmp_files_dir) free(tmp_files_dir); tmp_files_dir = strdup((yyvsp[(3) - (3)].str)); };
	}
    break;

  case 103:
#line 393 "parse_settings.y"
    {
		if(in_theme) yyerror("Setting 'pre_gui_script' is not allowed in theme file.");
		TTY_CHECK_COND { if (pre_gui_script) free(pre_gui_script); pre_gui_script = strdup((yyvsp[(3) - (3)].str)); };
	}
    break;

  case 104:
#line 400 "parse_settings.y"
    {
		if(in_theme) yyerror("Setting 'post_gui_script' is not allowed in theme file.");
		TTY_CHECK_COND { if (post_gui_script) free(post_gui_script); post_gui_script = strdup((yyvsp[(3) - (3)].str)); };
	}
    break;

  case 105:
#line 406 "parse_settings.y"
    { TTY_CHECK_COND {SSAVER_CHECK_COND screensaver_name = (yyvsp[(2) - (2)].str);} }
    break;

  case 106:
#line 407 "parse_settings.y"
    { TTY_CHECK_COND screensaver_name = (yyvsp[(2) - (4)].str);}
    break;

  case 107:
#line 410 "parse_settings.y"
    { TTY_CHECK_COND {SSAVER_CHECK_COND add_to_options((yyvsp[(1) - (1)].str));} }
    break;

  case 108:
#line 411 "parse_settings.y"
    { TTY_CHECK_COND {SSAVER_CHECK_COND add_to_options((yyvsp[(3) - (3)].str));} }
    break;

  case 109:
#line 416 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'x_sessions' is not allowed in theme file.");
	  TTY_CHECK_COND x_sessions_directory = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 110:
#line 424 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'test_sessions' is not allowed in theme file.");
	  TTY_CHECK_COND text_sessions_directory = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 111:
#line 431 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'xinit' is not allowed in theme file");
	  TTY_CHECK_COND xinit = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 112:
#line 438 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'xinit' is not allowed in theme file");
	  TTY_CHECK_COND x_server = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 113:
#line 445 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'x_args' is not allowed in theme file");
	  TTY_CHECK_COND x_args = strdup((yyvsp[(3) - (3)].str));
	}
    break;

  case 114:
#line 452 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'x_server_offset' is not allowed in theme file");
	  TTY_CHECK_COND x_server_offset = (yyvsp[(3) - (3)].ival);
	}
    break;

  case 115:
#line 459 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'x_server_tty' is not allowed in theme file.");
	  TTY_CHECK_COND x_serv_tty_mgmt = QINGY_TTY;
	}
    break;

  case 116:
#line 464 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'x_server_tty' is not allowed in theme file.");
	  TTY_CHECK_COND x_serv_tty_mgmt = UNUSED_TTY;
	}
    break;

  case 117:
#line 472 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'shutdown_policy' is not allowed in theme file.");
	  TTY_CHECK_COND shutdown_policy = EVERYONE;
	}
    break;

  case 118:
#line 477 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'shutdown_policy' is not allowed in theme file.");
	  TTY_CHECK_COND shutdown_policy = ROOT;
	}
    break;

  case 119:
#line 482 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'shutdown_policy' is not allowed in theme file.");
	  TTY_CHECK_COND shutdown_policy = NOONE;
	}
    break;

  case 120:
#line 490 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'last_user_policy' is not allowed in theme file.");
	  TTY_CHECK_COND last_user_policy = LU_GLOBAL;
	}
    break;

  case 121:
#line 495 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'last_user_policy' is not allowed in theme file.");
	  TTY_CHECK_COND last_user_policy = LU_TTY;
	}
    break;

  case 122:
#line 500 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'last_user_policy' is not allowed in theme file.");
	  TTY_CHECK_COND last_user_policy = LU_NONE;
	}
    break;

  case 123:
#line 508 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'last_session_policy' is not allowed in theme file.");
	  TTY_CHECK_COND last_session_policy = LS_USER;
	}
    break;

  case 124:
#line 513 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'last_session_policy' is not allowed in theme file.");
	  TTY_CHECK_COND last_session_policy = LS_TTY;
	}
    break;

  case 125:
#line 518 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'last_session_policy' is not allowed in theme file.");
	  TTY_CHECK_COND last_session_policy = LS_NONE;
	}
    break;

  case 126:
#line 526 "parse_settings.y"
    {
	if (in_theme) yyerror("Setting 'idle_timeout' is not allowed in theme file.");
	TTY_CHECK_COND idle_timeout = (yyvsp[(3) - (3)].ival);
}
    break;

  case 127:
#line 533 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'idle_action' is not allowed in theme file.");
	  TTY_CHECK_COND timeout_action = ST_LOGOUT;
	}
    break;

  case 128:
#line 538 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'idle_action' is not allowed in theme file.");
	  TTY_CHECK_COND timeout_action = ST_LOCK;
	}
    break;

  case 129:
#line 543 "parse_settings.y"
    {
	  if (in_theme) yyerror("Setting 'idle_action' is not allowed in theme file.");
	  TTY_CHECK_COND timeout_action = ST_NONE;
	}
    break;

  case 130:
#line 550 "parse_settings.y"
    { TTY_CHECK_COND {char *temp = get_random_theme(); set_theme_result=set_theme(temp); free(temp);} }
    break;

  case 131:
#line 551 "parse_settings.y"
    { TTY_CHECK_COND set_theme_result=set_theme((yyvsp[(3) - (3)].str)); }
    break;

  case 137:
#line 560 "parse_settings.y"
    { TTY_CHECK_COND {clear_background = 1; clear_background_is_set = 1;} }
    break;

  case 138:
#line 561 "parse_settings.y"
    { TTY_CHECK_COND {clear_background = 0; clear_background_is_set = 1;} }
    break;

  case 141:
#line 568 "parse_settings.y"
    {
    curs.enable = 1;
		curs.path   = NULL;
		curs.x_off  = 0;
		curs.y_off  = 0;
		if (!in_window)
			curs.window_id = -1;
		else
			curs.window_id = wind.id;
		add_cursor_to_list(&curs);
  }
    break;

  case 142:
#line 580 "parse_settings.y"
    {
    curs.enable = 0;
		curs.path   = NULL;
		curs.x_off  = 0;
		curs.y_off  = 0;
		if (!in_window)
			curs.window_id = -1;
		else
			curs.window_id = wind.id;
		add_cursor_to_list(&curs);
  }
    break;

  case 144:
#line 596 "parse_settings.y"
    {
		curs.enable    = 1;
		curs.path      = (yyvsp[(1) - (5)].str);
		curs.x_off     = (yyvsp[(3) - (5)].ival);
		curs.y_off     = (yyvsp[(5) - (5)].ival);
		if (!in_window)
			curs.window_id = -1;
		else
			curs.window_id = wind.id;
		add_cursor_to_list(&curs);
	}
    break;

  case 145:
#line 611 "parse_settings.y"
    { 
		TTY_CHECK_COND
		{
			default_text_color.R=(yyvsp[(3) - (3)].color)[3]; default_text_color.G=(yyvsp[(3) - (3)].color)[2]; 
			default_text_color.B=(yyvsp[(3) - (3)].color)[1]; default_text_color.A=(yyvsp[(3) - (3)].color)[0];
		}
	}
    break;

  case 146:
#line 619 "parse_settings.y"
    {
		TTY_CHECK_COND
		{
			default_text_color.R = (yyvsp[(3) - (9)].ival); default_text_color.G= (yyvsp[(5) - (9)].ival);
			default_text_color.B = (yyvsp[(7) - (9)].ival); default_text_color.A= (yyvsp[(9) - (9)].ival);
		}
	}
    break;

  case 147:
#line 627 "parse_settings.y"
    { 
		TTY_CHECK_COND
		{
			default_cursor_color.R=(yyvsp[(3) - (3)].color)[3]; default_cursor_color.G=(yyvsp[(3) - (3)].color)[2];
			default_cursor_color.B=(yyvsp[(3) - (3)].color)[1]; default_cursor_color.A=(yyvsp[(3) - (3)].color)[0];
		}
	}
    break;

  case 148:
#line 635 "parse_settings.y"
    { 
		TTY_CHECK_COND
		{
			default_cursor_color.R = (yyvsp[(3) - (9)].ival); default_cursor_color.G= (yyvsp[(5) - (9)].ival); 
			default_cursor_color.B = (yyvsp[(7) - (9)].ival); default_cursor_color.A= (yyvsp[(9) - (9)].ival); 
		}
	}
    break;

  case 149:
#line 643 "parse_settings.y"
    { 
		TTY_CHECK_COND
		{
			other_text_color.R=(yyvsp[(3) - (3)].color)[3]; other_text_color.G=(yyvsp[(3) - (3)].color)[2]; 
			other_text_color.B=(yyvsp[(3) - (3)].color)[1]; other_text_color.A=(yyvsp[(3) - (3)].color)[0];
		}
	}
    break;

  case 150:
#line 651 "parse_settings.y"
    { 
		TTY_CHECK_COND
		{
			other_text_color.R = (yyvsp[(3) - (9)].ival); other_text_color.G= (yyvsp[(5) - (9)].ival); 
			other_text_color.B = (yyvsp[(7) - (9)].ival); other_text_color.A= (yyvsp[(9) - (9)].ival);
		}
	}
    break;

  case 151:
#line 662 "parse_settings.y"
    {
		TTY_CHECK_COND
		{
			theme_xres = (yyvsp[(3) - (5)].ival); theme_yres = (yyvsp[(5) - (5)].ival);
		}
	}
    break;

  case 152:
#line 669 "parse_settings.y"
    {
		TTY_CHECK_COND
		{
			theme_xres = (yyvsp[(3) - (5)].ival); theme_yres = (yyvsp[(5) - (5)].ival);
		}
	}
    break;

  case 153:
#line 678 "parse_settings.y"
    { TTY_CHECK_COND background = StrApp((char**)NULL, theme_dir, (yyvsp[(3) - (3)].str), (char*)NULL); }
    break;

  case 154:
#line 679 "parse_settings.y"
    { TTY_CHECK_COND font       = StrApp((char**)NULL, theme_dir, (yyvsp[(3) - (3)].str), (char*)NULL); }
    break;

  case 155:
#line 683 "parse_settings.y"
    { TTY_CHECK_COND button_opacity          = (yyvsp[(3) - (3)].ival); }
    break;

  case 156:
#line 684 "parse_settings.y"
    { TTY_CHECK_COND window_opacity          = (yyvsp[(3) - (3)].ival); }
    break;

  case 157:
#line 685 "parse_settings.y"
    { TTY_CHECK_COND selected_window_opacity = (yyvsp[(3) - (3)].ival); }
    break;

  case 158:
#line 690 "parse_settings.y"
    {
	  if(in_theme) yyerror("Setting 'key_bindings' is not allowed in theme file.");
	}
    break;

  case 160:
#line 697 "parse_settings.y"
    {
		if (!add_to_keybindings(action, (yyvsp[(4) - (4)].str)))
			yyerror("An error occurred while parsing your keybingings configuration.");
	}
    break;

  case 161:
#line 703 "parse_settings.y"
    { action = DO_SLEEP;        }
    break;

  case 162:
#line 704 "parse_settings.y"
    { action = DO_NEXT_TTY;     }
    break;

  case 163:
#line 705 "parse_settings.y"
    { action = DO_PREV_TTY;     }
    break;

  case 164:
#line 706 "parse_settings.y"
    { action = DO_POWEROFF;     }
    break;

  case 165:
#line 707 "parse_settings.y"
    { action = DO_REBOOT;       }
    break;

  case 166:
#line 708 "parse_settings.y"
    { action = DO_SCREEN_SAVER; }
    break;

  case 167:
#line 709 "parse_settings.y"
    { action = DO_KILL;         }
    break;

  case 168:
#line 710 "parse_settings.y"
    { action = DO_TEXT_MODE;    }
    break;

  case 169:
#line 715 "parse_settings.y"
    {
		TTY_CHECK_COND
		{
			if (got_theme)
			{
				destroy_windows_list(windowsList); 
				windowsList = NULL;
				got_theme   = 0;
			}
			add_window_to_list(&wind);
			in_window=0;
		}
	}
    break;

  case 171:
#line 730 "parse_settings.y"
    { in_window=1; }
    break;

  case 172:
#line 732 "parse_settings.y"
    { TTY_CHECK_COND wind.x=(yyvsp[(3) - (3)].ival);                        }
    break;

  case 173:
#line 733 "parse_settings.y"
    { TTY_CHECK_COND wind.y=(yyvsp[(3) - (3)].ival);                        }
    break;

  case 174:
#line 734 "parse_settings.y"
    { TTY_CHECK_COND wind.type     = get_win_type((yyvsp[(3) - (3)].str)); }
    break;

  case 175:
#line 735 "parse_settings.y"
    { TTY_CHECK_COND wind.width    = (yyvsp[(3) - (3)].ival);               }
    break;

  case 176:
#line 736 "parse_settings.y"
    { TTY_CHECK_COND wind.height   = (yyvsp[(3) - (3)].ival);               }
    break;

  case 178:
#line 738 "parse_settings.y"
    { TTY_CHECK_COND wind.content  = strdup((yyvsp[(3) - (3)].str));       }
    break;

  case 179:
#line 739 "parse_settings.y"
    { TTY_CHECK_COND wind.linkto   = strdup((yyvsp[(3) - (3)].str));       }
    break;

  case 180:
#line 740 "parse_settings.y"
    { TTY_CHECK_COND wind.polltime = (yyvsp[(3) - (3)].ival);               }
    break;

  case 185:
#line 747 "parse_settings.y"
    { TTY_CHECK_COND wind.command = NULL;       }
    break;

  case 186:
#line 748 "parse_settings.y"
    { TTY_CHECK_COND wind.command = strdup((yyvsp[(1) - (1)].str)); }
    break;

  case 187:
#line 751 "parse_settings.y"
    { TTY_CHECK_COND wind.text_orientation = LEFT;   }
    break;

  case 188:
#line 752 "parse_settings.y"
    { TTY_CHECK_COND wind.text_orientation = CENTER; }
    break;

  case 189:
#line 753 "parse_settings.y"
    { TTY_CHECK_COND wind.text_orientation = RIGHT;  }
    break;

  case 190:
#line 756 "parse_settings.y"
    { TTY_CHECK_COND wind.text_size = TINY;    }
    break;

  case 191:
#line 757 "parse_settings.y"
    { TTY_CHECK_COND wind.text_size = SMALLER; }
    break;

  case 192:
#line 758 "parse_settings.y"
    { TTY_CHECK_COND wind.text_size = SMALL;   }
    break;

  case 193:
#line 759 "parse_settings.y"
    { TTY_CHECK_COND wind.text_size = MEDIUM;  }
    break;

  case 194:
#line 760 "parse_settings.y"
    { TTY_CHECK_COND wind.text_size = LARGE;   }
    break;

  case 195:
#line 765 "parse_settings.y"
    { 
		TTY_CHECK_COND
		{
			wind.text_color = (color_t *) calloc(1, sizeof(color_t));
			wind.text_color->R=(yyvsp[(3) - (3)].color)[3]; wind.text_color->G=(yyvsp[(3) - (3)].color)[2]; 
			wind.text_color->B=(yyvsp[(3) - (3)].color)[1]; wind.text_color->A=(yyvsp[(3) - (3)].color)[0];
		}
	}
    break;

  case 196:
#line 774 "parse_settings.y"
    { 
		TTY_CHECK_COND
		{
			wind.text_color = (color_t *) calloc(1, sizeof(color_t));
			wind.text_color->R = (yyvsp[(3) - (9)].ival); wind.text_color->G = (yyvsp[(5) - (9)].ival);
			wind.text_color->B = (yyvsp[(7) - (9)].ival); wind.text_color->A = (yyvsp[(9) - (9)].ival);
		}
	}
    break;

  case 197:
#line 783 "parse_settings.y"
    {	
		TTY_CHECK_COND
		{
			wind.cursor_color = (color_t *) calloc(1, sizeof(color_t));
			wind.cursor_color->R=(yyvsp[(3) - (3)].color)[3]; wind.cursor_color->G=(yyvsp[(3) - (3)].color)[2]; 
			wind.cursor_color->B=(yyvsp[(3) - (3)].color)[1]; wind.cursor_color->A=(yyvsp[(3) - (3)].color)[0];
		}
	}
    break;

  case 198:
#line 792 "parse_settings.y"
    {
		TTY_CHECK_COND
		{
			wind.cursor_color = (color_t *) calloc(1, sizeof(color_t));
			wind.cursor_color->R = (yyvsp[(3) - (9)].ival); wind.cursor_color->G = (yyvsp[(5) - (9)].ival);
			wind.cursor_color->B = (yyvsp[(7) - (9)].ival); wind.cursor_color->A = (yyvsp[(9) - (9)].ival);
		}
	}
    break;


/* Line 1267 of yacc.c.  */
#line 2838 "parse_settings.c"
      default: break;
    }
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
      {
	YYSIZE_T yysize = yysyntax_error (0, yystate, yychar);
	if (yymsg_alloc < yysize && yymsg_alloc < YYSTACK_ALLOC_MAXIMUM)
	  {
	    YYSIZE_T yyalloc = 2 * yysize;
	    if (! (yysize <= yyalloc && yyalloc <= YYSTACK_ALLOC_MAXIMUM))
	      yyalloc = YYSTACK_ALLOC_MAXIMUM;
	    if (yymsg != yymsgbuf)
	      YYSTACK_FREE (yymsg);
	    yymsg = (char *) YYSTACK_ALLOC (yyalloc);
	    if (yymsg)
	      yymsg_alloc = yyalloc;
	    else
	      {
		yymsg = yymsgbuf;
		yymsg_alloc = sizeof yymsgbuf;
	      }
	  }

	if (0 < yysize && yysize <= yymsg_alloc)
	  {
	    (void) yysyntax_error (yymsg, yystate, yychar);
	    yyerror (yymsg);
	  }
	else
	  {
	    yyerror (YY_("syntax error"));
	    if (yysize != 0)
	      goto yyexhaustedlab;
	  }
      }
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse look-ahead token after an
	 error, discard it.  */

      if (yychar <= YYEOF)
	{
	  /* Return failure if at end of input.  */
	  if (yychar == YYEOF)
	    YYABORT;
	}
      else
	{
	  yydestruct ("Error: discarding",
		      yytoken, &yylval);
	  yychar = YYEMPTY;
	}
    }

  /* Else will try to reuse look-ahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule which action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;


      yydestruct ("Error: popping",
		  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  *++yyvsp = yylval;


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEOF && yychar != YYEMPTY)
     yydestruct ("Cleanup: discarding lookahead",
		 yytoken, &yylval);
  /* Do not reclaim the symbols of the rule which action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
		  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  /* Make sure YYID is used.  */
  return YYID (yyresult);
}


#line 802 "parse_settings.y"


